@@ -37,6 +37,12 @@ class UnbindEslDeviceRequest(RpcRequest):
 	def set_ExtraParams(self,ExtraParams):
 		self.add_body_params('ExtraParams', ExtraParams)
 
+	def get_ContainerName(self):
+		return self.get_body_params().get('ContainerName')
+
+	def set_ContainerName(self,ContainerName):
+		self.add_body_params('ContainerName', ContainerName)
+
 	def get_StoreId(self):
 		return self.get_body_params().get('StoreId')
 
